@@ -7,13 +7,21 @@
 #' @details Will print the head of a \code{sim_setup} to the console, after converting it to a \code{data.frame}.
 #' @rdname showMethods
 #' @export
-setMethod("show", "sim_setup",
-          function(object) {
-            # this is essentially dplyr::print.tbl_df but there is no obvious 
-            # constructor for tbl_df ...
-            dat <- as.data.frame(object)
-            cat("data.frame ", dim_desc(dat), "\n", sep = "")
-            cat("\n")
-            print(trunc_mat(dat, n = 6, width = NULL))
-            invisible(dat)
-          })
+setMethod("show", "sim_setup", function(object) {
+  # this is essentially dplyr::print.tbl_df but there is no obvious 
+  # constructor for tbl_df ...
+  run <- sim_run_once(object)
+  if (inherits(run, "data.frame")) {
+    dat <- as.data.frame(run)
+    cat("data.frame ", dim_desc(dat), "\n", sep = "")
+    cat("\n")
+    print(trunc_mat(dat, n = 6, width = NULL))
+    invisible(dat)
+  } else if (isS4(run)) {
+    show(run)
+    invisible(run)
+  } else {
+    print(run)
+  }
+})
+
